#### Viirret et al.: 
#### "Ecosystem services at the Archipelago Sea Biosphere Reserve in Finland - a visitor perspective" 
#### Analysis and plotting script ####

# Set working directory:
# setwd("...")

### Start with habitats: ###

## Read the habitat perception data:
Habitats<-read.table("Habitat_perceptions.txt", header=T, sep="\t")

# Then, some initial plotting

hist(Habitats$Reed_bed) # Need to make a barplot, not a histogram

Reed_bed<-table(Habitats$Reed_bed) # Calculate counts
Reed_bed
barplot(Reed_bed, main="Reedbed", xlab="Perception") # Yes, this seems better.

# The same needs to be done to the eight other habitat types

Bladder_wrack<-table(Habitats$Bladder_wrack)
Bladder_wrack
Bladder_wrack$"1"<-as.integer(0)
Bladder_wrack<-unlist(Bladder_wrack, recursive = TRUE, use.names = TRUE)
barplot(Bladder_wrack, main="Bladder wrack", xlab="Perception")
# X axis needs to be fixed
Bladder_wrack_reorder<-c(0,7,24,41) # Ok, this is easier and works better
labs<-c("1","2","3","4") # This may not be needed after all
barplot(Bladder_wrack_reorder, main="Bladder wrack", xlab="Perception")
# Also, I need to set the y axis limits so that all plots are comparable.

Bird_islet<-table(Habitats$Bird_islet)
barplot(Bird_islet, main="Bird islet", xlab="Perception")

Sand_beach<-table(Habitats$Sand_beach)
barplot(Sand_beach, main="Sand beach", xlab="Perception")

# Reedbed here, so the order matches the MS

Seaside_meadow<-table(Habitats$Seaside_meadow)
barplot(Seaside_meadow, main="Seaside meadow", xlab="Perception")

Dry_meadow<-table(Habitats$Dry_meadow)
barplot(Dry_meadow, main="Dry meadow", xlab="Perception")

Pasture_meadow<-table(Habitats$Wooded_pasture_or_meadow)
barplot(Pasture_meadow, main="Wooded pasture or meadow", xlab="Perception")

Forest<-table(Habitats$Broad_leaf_forest)
barplot(Forest, main="Broadleaf forest", xlab="Perception")
Forest
Forest_reorder<-c(0,2,21,49)
barplot(Forest_reorder, main="Broadleaf forest", xlab="Perception")

Juniper<-table(Habitats$Juniper_thicket)
barplot(Juniper, main="Juniper thicket", xlab="Perception")

## The highest frequency is 55 from dry meadow, so the y axis could range from 0 to 55 or 60.

## A final script for Figure 2 (Habitat perceptions)

pdf("Fig_2.pdf", height = 8, width = 8)

opar <- par(mfrow=c(3,3), cex=0.6, mar=c(2, 2, 2, 1)+0.1, oma = c(4, 4, 0.5, 0.5))

# Set a 9 panel figure, make characters smaller, define inner margins, define outer margins

# Panel A: Bladder wrack
# First create an empty plot with appropriate axes
# plot(1, type = 'n', xlim = c(1,4), ylim=c(0,55), xlab="", ylab="", lty = 1, axes = FALSE)
barplot(Bladder_wrack_reorder, main="Bladder wrack", xlab="", xaxt="n", ylim=c(0,55))

# Panel B: Bird islet
barplot(Bird_islet, main="Bird islet", xlab="", xaxt="n", ylim=c(0,55))

# Panel C: Sand beach
barplot(Sand_beach, main="Sand beach", xlab="", xaxt="n", ylim=c(0,55))

# Panel D: Reedbed
barplot(Reed_bed, main="Reedbed", xlab="", xaxt="n", ylim=c(0,55))

# Panel E: Seaside meadow
barplot(Seaside_meadow, main="Seaside meadow", xlab="", xaxt="n", ylim=c(0,55))

# Panel F: Dry meadow
barplot(Dry_meadow, main="Dry meadow", xlab="", xaxt="n", ylim=c(0,55))

# Panel G: Wood-pasture or wooded meadow
barplot(Pasture_meadow, main="Wooded pasture or meadow", xlab="", ylim=c(0,55))

# Panel H: Broadleaf forest
barplot(Forest_reorder, main="Broadleaf forest", xlab="", names.arg=labs, ylim=c(0,55))

# Panel I: Juniper thicket
barplot(Juniper, main="Juniper thicket", xlab="", ylim=c(0,55))

mtext("Perception", side = 1, outer = TRUE, cex = 0.9, line = 2.2) # Add a shared x axis label
mtext("Frequency", side = 2, outer = TRUE, cex = 0.9, line = 2.2) # Add a shared y axis label

dev.off()

par(opar)

### Next, perceptions on ecosystem services ###

## Read the habitat perception data:
ES<-read.table("ES_perceptions.txt", header=T, sep="\t")

## Calculate counts for barplots:

str(ES)

Hunt_fish<-table(ES$Hunting_fishing)
Hunt_fish
Hunt_fish_reorder<-c(22,31,11,6)
barplot(Hunt_fish_reorder)

Coll_harv<-table(ES$Collecting_harvesting)
Coll_harv
Coll_harv_reorder<-c(0,20,36,17)
barplot(Coll_harv_reorder)

Energy<-table(ES$Energy_production)
Energy
Energy_reorder<-c(6,17,30,6)
barplot(Energy_reorder)

Quality<-table(ES$Water_soil_quality)
Quality
Quality_reorder<-c(0,2,12,59)
barplot(Quality_reorder)

Scenery<-table(ES$Scenery)
Scenery
Scenery_reorder<-c(0,1,15,56)
barplot(Scenery_reorder)

Culture<-table(ES$Cultural_value)
Culture
Culture_reorder<-c(0,2,21,48)
barplot(Culture_reorder)

Recreation<-table(ES$Recreation)
Recreation
Recreation_reorder<-c(0,3,24,44)
barplot(Recreation_reorder)

Biodiversity<-table(ES$Biodiversity)
Biodiversity
Biodiversity_reorder<-c(0,4,19,51)
barplot(Biodiversity_reorder)

## A final script for Figure 3 (Ecosystem services perceptions)

pdf("Fig_3.pdf", height = 5, width = 8)

opar <- par(mfrow=c(2,4), cex=0.6, mar=c(2, 2, 2, 1)+0.1, oma = c(4, 4, 0.5, 0.5))

# Set an 8 panel figure, make characters smaller, define inner margins, define outer margins

# Panel A: Hunting and fishing
barplot(Hunt_fish_reorder, main="Hunting and fishing", xlab="", xaxt="n", ylim=c(0,60))

# Panel B: Berry and mushroom harvesting and collecting
barplot(Coll_harv_reorder, main="Collecting and harvesting", xlab="", xaxt="n", ylim=c(0,60))

# Panel C: Energy production
barplot(Energy_reorder, main="Energy production", xlab="", xaxt="n", ylim=c(0,60))

# Panel D: Quality of water and soil
barplot(Quality_reorder, main="Water and soil quality", xlab="", xaxt="n", ylim=c(0,60))

# Panel E: Scenery
barplot(Scenery_reorder, main="Scenery", xlab="", names.arg=labs, ylim=c(0,60))

# Panel F: Cultural value
barplot(Culture_reorder, main="Cultural value", xlab="", names.arg=labs, ylim=c(0,60))

# Panel G: Recreational value
barplot(Recreation_reorder, main="Recreational value", xlab="", names.arg=labs, ylim=c(0,60))

# Panel H: Biodiversity
barplot(Biodiversity_reorder, main="Biodiversity", xlab="", names.arg=labs, ylim=c(0,60))

mtext("Perception", side = 1, outer = TRUE, cex = 0.9, line = 2.2) # Add a shared x axis label
mtext("Frequency", side = 2, outer = TRUE, cex = 0.9, line = 2.2) # Add a shared y axis label

dev.off()

par(opar)

### Next, radar or spider plots with cross-tabulated data (uses modes as values)

# Load the library
library(fmsb)

Habes<-read.table("Habitats_ESs.txt", header=T, row.names=1, sep="\t")

## Final script for Figure 4:

pdf("Fig_4.pdf", height = 8, width = 8)

opar <- par(mfrow=c(3,3), cex=0.6, mar=c(2, 2, 2, 1)+0.1, oma = c(0.5, 0.5, 0.5, 0.5))

# Set a 9 panel figure, make characters smaller, define inner margins, define outer margins

## Panel A: I need to pick the values for Bladder wrack to a separate data table
BW<-Habes[1,]

# Next, I'll add the max (4) and min (1) values to the eight columns of the table
BW<-rbind(rep(4,8), rep(1,8), BW)

# And now I can draw the plot:
radarchart(BW, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Bladder wrack")

## Panel B: Bird islet

BI<-Habes[2,]
BI<-rbind(rep(4,8), rep(1,8), BI)
radarchart(BI, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Bird islet")

## Panel C: Sand beach

SB<-Habes[3,]
SB<-rbind(rep(4,8), rep(1,8), SB)
radarchart(SB, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Sand beach")

## Panel D: Reedbed

RB<-Habes[4,]
RB<-rbind(rep(4,8), rep(1,8), RB)
radarchart(RB, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Reedbed")

## Panel E: Seaside meadow

SM<-Habes[5,]
SM<-rbind(rep(4,8), rep(1,8), SM)
radarchart(SM, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Seaside meadow")

## Panel F: Dry meadow

DM<-Habes[6,]
DM<-rbind(rep(4,8), rep(1,8), DM)
radarchart(DM, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Dry meadow")

## Panel G: Wooded pasture or meadow

WP<-Habes[7,]
WP<-rbind(rep(4,8), rep(1,8), WP)
radarchart(WP, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Wooded pasture or meadow")

## Panel H: Broadleaf forest

BF<-Habes[8,]
BF<-rbind(rep(4,8), rep(1,8), BF)
radarchart(BF, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Broadleaf forest")

## Panel I: Juniper thicket

JT<-Habes[9,]
JT<-rbind(rep(4,8), rep(1,8), JT)
radarchart(JT, axistype = 1, axislabcol="black", caxislabels=seq(0,100,25), title="Juniper thicket")

dev.off()

par(opar)